/*
  Universal 8bit Graphics Library
  
  Copyright (c) 2012, olikraus@gmail.com
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this list 
    of conditions and the following disclaimer.
    
  * Redistributions in binary form must reproduce the above copyright notice, this 
    list of conditions and the following disclaimer in the documentation and/or other 
    materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND 
  CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
  STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.  
  
*/

#include "u8g.h"

#if defined(__AVR__)
#include <avr/interrupt.h>
#include <avr/io.h>
#endif

u8g_t u8g;

void u8g_setup(void)
{  
    u8g_Init8Bit(&u8g, &u8g_dev_st7920_128x64_8bit,
                PN(3, 0), PN(3, 1), PN(3, 2), PN(3, 3), PN(3, 4), PN(3, 5), PN(3, 6), PN(3, 7), // PORT DATE               
                PN(2, 4),    // ENABLE
                U8G_PIN_NONE,
                U8G_PIN_NONE,
                PN(2, 2),    // RS / DI
                PN(2, 3),    // RW
                PN(2, 5));   // RESET
}

void sys_init(void)
{
#if defined(__AVR__)
    /* select minimal prescaler (max system speed) */
    CLKPR = 0x80;
    CLKPR = 0x00;
#endif
}

void draw(void)
{
    int i;
    
    u8g_SetFont(&u8g, u8g_font_gdr9);
    u8g_DrawStr(&u8g, 0, 11, " 2048 2048 2048 2048 ");
    for (i = 0; i < 4; ++i)
        u8g_DrawFrame(&u8g, i * 32, 0, 33, 14);
        
    u8g_DrawStr(&u8g, 0, 26, " 2048 2048 2048 2048 ");
    //for (i = 0; i < 4; ++i)
      //  u8g_DrawFrame(&u8g, i * 32, 13, 33, 14);
        
    u8g_DrawStr(&u8g, 0, 41, " 2048 2048 2048 2048 ");
    //for (i = 0; i < 4; ++i)
      //  u8g_DrawFrame(&u8g, i * 32, 26, 33, 14);
        
    u8g_DrawStr(&u8g, 0, 56, " 2048 2048 2048 2048 "); 
    //for (i = 0; i < 4; ++i)
      //  u8g_DrawFrame(&u8g, i * 32, 39, 33, 14); 
}

int main(void)
{
    // JTAG-ul vietii
    MCUCR |= (1 << JTD); 
    MCUCR |= (1 << JTD); 

    sys_init();
    u8g_setup();

    for ( ; ; )
    {  
        u8g_FirstPage(&u8g);
        do
        {
          draw();
        } while (u8g_NextPage(&u8g));
        u8g_Delay(100);
    }
}

